@@ -19,10 +19,9 @@ from enum import Enum
 import warnings
 from docstring_parser import parse, compose
 from qtpy.QtWidgets import QWidget, QDockWidget
-from qtpy.QtGui import QIcon
 
 from psygnal import Signal
-from magicgui.signature import MagicParameter, split_annotated_type
+from magicgui.signature import MagicParameter
 from magicgui.widgets import (
     FunctionGui,
     FileEdit,
@@ -65,7 +64,11 @@ from ..utils import (
 )
 from ..widgets import Separator, FreeWidget
 from ..fields import MagicField
-from ..signature import MagicMethodSignature, get_additional_option
+from ..signature import (
+    MagicMethodSignature,
+    get_additional_option,
+    split_annotated_type,
+)
 from ..wrappers import upgrade_signature
 
 if TYPE_CHECKING:
@@ -88,24 +91,24 @@ class PopUpMode(Enum):
     parentsub = "parentsub"
 
 
-def _msgbox_raising(e, parent):
+def _msgbox_raising(e: Exception, parent: Widget):
     from ._message_box import QtErrorMessageBox
 
     return QtErrorMessageBox.raise_(e, parent=parent.native)
 
 
-def _stderr_raising(e, parent):
+def _stderr_raising(e: Exception, parent: Widget):
     pass
 
 
-def _stdout_raising(e, parent):
+def _stdout_raising(e: Exception, parent: Widget):
     print(f"{e.__class__.__name__}: {e}")
 
 
-def _napari_notification_raising(e, parent):
+def _napari_notification_raising(e: Exception, parent: Widget):
     from napari.utils.notifications import show_error
 
-    show_error(str(e))
+    return show_error(str(e))
 
 
 class ErrorMode(Enum):
@@ -517,42 +520,41 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
 
         _found = 0
         _n_match = len(matcher)
-
         for child_instance in self._iter_child_magicclasses():
             _name = child_instance.__class__.__name__
             if _name in matcher:
+                n_children = len(child_instance)
+
                 # get the position of predefined child widget
                 try:
                     index = _get_index(child_instance, method_name)
                     new = False
                 except ValueError:
-                    index = -1
+                    index = n_children
                     new = True
 
-                self._fast_insert(-1, widget)
+                self._fast_insert(len(self), widget)
                 copy = _name in copyto
 
                 if isinstance(widget, FunctionGui):
                     if copy:
                         widget = widget.copy()
                     if new:
-                        child_instance._fast_insert(-1, widget)
+                        child_instance._fast_insert(n_children, widget)
                     else:
-                        del child_instance[index]
+                        del child_instance[index - 1]
                         child_instance._fast_insert(index, widget)
 
                 else:
                     widget.visible = copy
                     if new:
                         child_widget = child_instance._create_widget_from_method(
-                            lambda x: None
+                            _empty_func(method_name)
                         )
                         child_widget.text = widget.text
-                        child_instance._fast_insert(-1, child_widget)
+                        child_instance._fast_insert(n_children, child_widget)
                     else:
-                        child_widget: PushButtonPlus | AbstractAction = child_instance[
-                            index
-                        ]
+                        child_widget = child_instance[index]
 
                     child_widget.changed.disconnect()
                     child_widget.changed.connect(widget.changed)
@@ -660,7 +662,6 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
                         title = Separator(
                             orientation="horizontal", title=text, button=True
                         )
-                        title.btn_text = "-"
                         # TODO: should remove mgui from self?
                         title.btn_clicked.connect(mgui.hide)
                         mgui.insert(0, title)
@@ -919,7 +920,8 @@ def _create_gui_method(self: BaseGui, obj: MethodType):
     all_params: list[inspect.Parameter] = []
     for param in func.__signature__.parameters.values():
         if isinstance(param.annotation, _AnnotatedAlias):
-            param = MagicParameter.from_parameter(param)
+            annot, opt = split_annotated_type(param.annotation)
+            param = MagicParameter.from_parameter(param, gui_options=opt)
 
         if isinstance(param, MagicParameter):
             _param = MagicParameter(
@@ -1474,3 +1476,10 @@ def _cleanup_tb(tb: TracebackType):
             break
         current_tb = current_tb.tb_next
     return tb
+
+
+def _empty_func(name: str) -> Callable[[Any], None]:
+    """Create a named function that does nothing."""
+    f = lambda x: None
+    f.__name__ = name
+    return f
