@@ -26,6 +26,8 @@ from magicgui.application import use_app
 from . import get_signature, move_to_screen_center
 from .qtsignal import QtSignal
 
+from ..widgets.containers import FrameContainer
+
 if TYPE_CHECKING:
     from .._gui import BaseGui
     from .._gui.mgui_ext import PushButtonPlus, Action
@@ -237,9 +239,20 @@ class Timer:
         return fmt.format(hour=int(hour), min=int(min), sec=int(sec))
 
 
-class DefaultProgressBar(Container, _SupportProgress):
+class _ProgressBarContainer(Container):
+    def __init__(self):
+        super().__init__(labels=False)
+        self.margins = (2, 2, 2, 2)
+        self.native.setWindowTitle("Progress")
+        self.native.layout().setAlignment(Qt.AlignmentFlag.AlignTop)
+
+
+class DefaultProgressBar(FrameContainer, _SupportProgress):
     """The default progressbar widget."""
 
+    # The outer container
+    _CONTAINER = _ProgressBarContainer()
+
     def __init__(self, max: int = 1):
         self.progress_label = Label(value="Progress")
         self.pbar = ProgressBar(value=0, max=max)
@@ -253,7 +266,7 @@ class DefaultProgressBar(Container, _SupportProgress):
         )
         cnt.margins = (0, 0, 0, 0)
         self.footer = cnt
-        self.pbar.min_width = 360
+        self.pbar.min_width = 240
         self._timer = Timer()
         self._time_signal = QtSignal()
         self._time_signal.connect(self._on_timer_updated)
@@ -312,11 +325,39 @@ class DefaultProgressBar(Container, _SupportProgress):
     def max(self, v):
         self.pbar.max = v
 
+    def show(self):
+        parent = self.native.parent()
+        self._CONTAINER.append(self)
+        if self._CONTAINER.parent is None:
+            self._CONTAINER.native.setParent(
+                parent,
+                self._CONTAINER.native.windowFlags(),
+            )
+        if not self._CONTAINER.visible:
+            self._CONTAINER.show()
+            move_to_screen_center(self._CONTAINER.native)
+        return None
+
+    def close(self):
+        for i, wdt in enumerate(self._CONTAINER):
+            if wdt is self:
+                break
+        self._CONTAINER.pop(i)
+        self._CONTAINER.height = 1  # minimize height
+        if len(self._CONTAINER) == 0:
+            self._CONTAINER.close()
+        return None
+
     def set_description(self, desc: str):
         """Set description as the label of the progressbar."""
         self.progress_label.value = desc
         return None
 
+    def set_title(self, title: str):
+        """Set the groupbox title."""
+        self.name = title
+        return None
+
     def set_worker(self, worker: GeneratorWorker | FunctionWorker):
         """Set currently running worker."""
         self._worker = worker
@@ -581,6 +622,8 @@ class thread_worker:
                 if hasattr(pbar, "set_worker"):
                     # if _SupportProgress object support set_worker
                     pbar.set_worker(worker)
+                if hasattr(pbar, "set_title"):
+                    pbar.set_title(self._func.__name__.replace("_", " "))
 
             _obj: PushButtonPlus | Action = gui[self._func.__name__]
             if _obj.running:
@@ -671,7 +714,7 @@ class thread_worker:
             if isinstance(_pbar, Widget) and _pbar.parent is None:
                 # Popup progressbar as a splashscreen if it is not a child widget.
                 _pbar.native.setParent(gui.native, self.__class__._WINDOW_FLAG)
-                move_to_screen_center(_pbar.native)
+
         else:
             _pbar.max = total
 
