@@ -2,36 +2,50 @@ from __future__ import annotations
 import sys
 import logging
 from pathlib import Path
-from contextlib import contextmanager
+from contextlib import contextmanager, suppress
 from qtpy import QtWidgets as QtW, QtGui, QtCore
 from qtpy.QtCore import Qt, Signal
 from magicgui.backends._qtpy.widgets import QBaseWidget
 from magicgui.widgets import Widget
 import logging
 from typing import TYPE_CHECKING, Any, Union, overload
+
 from ..utils import rst_to_html
 
-try:
-    import numpy as np
-    import matplotlib as mpl
-    import matplotlib.pyplot as plt
-    from matplotlib.backends.backend_agg import FigureCanvasAgg
-
-    FigureCanvas = FigureCanvasAgg
-    MATPLOTLIB_AVAILABLE = True
-
-except ImportError:
-    MATPLOTLIB_AVAILABLE = False
-
 if TYPE_CHECKING:
     import numpy as np
     from matplotlib.figure import Figure
-    from PIL import Image
 
 # See https://stackoverflow.com/questions/28655198/best-way-to-display-logs-in-pyqt
 
+# Variable "FigureCanvas" should globally updated to plot figure inside the logger
+# However, importing FigureCanvasAgg should be done lazily. Here's how to hack
+# this procedure.
+class FigureCanvasType:
+    def __init__(self):
+        self._canvas_type = None
+
+    @property
+    def FigureCanvasAgg(self):
+        if self._canvas_type is None:
+            from matplotlib.backends.backend_agg import FigureCanvasAgg
+
+            self._canvas_type = FigureCanvasAgg
+        return self._canvas_type
+
+    def __getattr__(self, name):
+        return getattr(self.FigureCanvasAgg, name)
+
+    def __call__(self, *args: Any, **kwds: Any) -> Any:
+        return self.FigureCanvasAgg(*args, **kwds)
+
+
+FigureCanvas = FigureCanvasType()
+
 
 class Output:
+    """Logger output types."""
+
     TEXT = 0
     HTML = 1
     IMAGE = 2
@@ -62,23 +76,25 @@ class QtLogger(QtW.QTextEdit):
         self._last_save_path = None
 
     def update(self, output: tuple[int, Printable]):
-        output_type, obj = output
-        if output_type == Output.TEXT:
-            self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
-            self.insertPlainText(obj)
-            self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
-        elif output_type == Output.HTML:
-            self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
-            self.insertHtml(obj)
-            self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
-        elif output_type == Output.IMAGE:
-            cursor = self.textCursor()
-            cursor.insertImage(obj)
-            self.insertPlainText("\n\n")
-            self.verticalScrollBar().setValue(self.verticalScrollBar().maximum())
-        else:
-            raise TypeError("Wrong type.")
-        self._post_append()
+        with suppress(RuntimeError):
+            output_type, obj = output
+            if output_type == Output.TEXT:
+                self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
+                self.insertPlainText(obj)
+                self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
+            elif output_type == Output.HTML:
+                self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
+                self.insertHtml(obj)
+                self.moveCursor(QtGui.QTextCursor.MoveOperation.End)
+            elif output_type == Output.IMAGE:
+                cursor = self.textCursor()
+                cursor.insertImage(obj)
+                self.insertPlainText("\n\n")
+                self.verticalScrollBar().setValue(self.verticalScrollBar().maximum())
+            else:
+                raise TypeError("Wrong type.")
+            self._post_append()
+        return None
 
     def appendText(self, text: str):
         """Append text in the main thread."""
@@ -126,7 +142,7 @@ class QtLogger(QtW.QTextEdit):
 
     def _copy_image(self, name):
         image = self._get_image(name)
-        QtW.QApplication.clipboard().setImage(image)
+        return QtW.QApplication.clipboard().setImage(image)
 
     def _save_image(self, name, format="PNG"):
         """Shows a save dialog for the ImageResource with 'name'."""
@@ -142,6 +158,7 @@ class QtLogger(QtW.QTextEdit):
             image = self._get_image(name)
             image.save(filename, format)
             self._last_save_path = Path(filename).parent
+        return None
 
     def _get_image(self, name):
         """Returns the QImage stored as the ImageResource with 'name'."""
@@ -218,8 +235,10 @@ class Logger(Widget, logging.Handler):
         )
 
     def emit(self, record):
+        """Handle the logging event."""
         msg = self.format(record)
         self.print(msg)
+        return None
 
     def clear(self):
         """Clear all the histories."""
@@ -309,15 +328,21 @@ class Logger(Widget, logging.Handler):
                 height = 240
 
         if width is None:
-            image = image.scaledToHeight(height, QtCore.Qt.SmoothTransformation)
+            image = image.scaledToHeight(
+                height, Qt.TransformationMode.SmoothTransformation
+            )
         else:
-            image = image.scaledToWidth(width, QtCore.Qt.SmoothTransformation)
+            image = image.scaledToWidth(
+                width, Qt.TransformationMode.SmoothTransformation
+            )
 
         self.native.appendImage(image)
         return None
 
     def print_figure(self, fig: Figure) -> None:
         """Print matplotlib Figure object like inline plot."""
+        import numpy as np
+
         fig.canvas.draw()
         data = np.asarray(fig.canvas.renderer.buffer_rgba(), dtype=np.uint8)
         self.print_image(data)
@@ -325,11 +350,12 @@ class Logger(Widget, logging.Handler):
         return None
 
     def write(self, msg) -> None:
+        """Handle the print event."""
         self.print(msg, end="")
         return None
 
     def flush(self):
-        pass
+        """Do nothing."""
 
     def close(self) -> None:
         # This method collides between magicgui.widgets.Widget and logging.Handler.
@@ -365,7 +391,10 @@ class Logger(Widget, logging.Handler):
     @contextmanager
     def set_plt(self, style: str = None, rc_context: dict[str, Any] = {}):
         """A context manager for inline plot in the logger widget."""
-        if not MATPLOTLIB_AVAILABLE:
+        try:
+            import matplotlib as mpl
+            import matplotlib.pyplot as plt
+        except ImportError:
             yield self
             return None
         self.__class__.current_logger = self
@@ -393,6 +422,8 @@ class Logger(Widget, logging.Handler):
         return None
 
     def _get_proper_plt_style(self) -> dict[str, Any]:
+        import matplotlib.pyplot as plt
+
         color = self._widget._qwidget._get_background_color()[:3]
         is_dark = sum(color) < 382.5  # 255*3/2
         if is_dark:
@@ -415,6 +446,7 @@ class Logger(Widget, logging.Handler):
 # https://github.com/ipython/matplotlib-inline
 def show(close=True, block=None):
     logger = Logger.current_logger
+    import matplotlib.pyplot as plt
     from matplotlib._pylab_helpers import Gcf
 
     try:
